% CalculationProofProp6.m
%
% Supplementary file to the proof of Proposition 6 in [1].
%
% The script performs the symbolic calculations to show that
%       a^2 * (pbar+d) / p1 * g'(pbar+d) < 1
% (see eq. (53)).
%
% --
% Supplementary material to
%
% [1] S. Trimpe, R. D'Andrea, "Event-Based State Estimation with 
% Variance-Based Triggering", IEEE Transactions on Automatic Control, 
% Special Issue on Control of Cyber-Physical Systems.
%
% Copyright:
% Sebastian Trimpe
% Max Planck Institute for Intelligent Systems
% strimpe(at)tuebingen.mpg.de
% March 2014
%

% Revision history
% [Dec 12, ST]   first version
% [Dec 13, ST]   adapt equation numbers etc. to revised version of the paper
% [10.03.14, ST] adapt to revised version of the paper


clear all;
clc;


%% Symbolic variables and expressions
% Problem parameters as defined in [1].  
syms a c d real;         % d for $\delta$

% Auxiliary variables
syms p S pbar real;  % pbar for $\bar{p}$

% Function g
g = a^2*p + 1 - a^2*c^2*p^2/(c^2*p+1);



%% Problem statement.
disp('#######################');
disp('## Problem Statement ##');
disp('#######################');

disp(' ');
disp('This script performs the symbolic calculations to show that ');
disp(' ');
disp('   a^2 * (pbar+d) / p1 * g''(pbar+d) < 1   ');
disp(' ');
disp('(cf. eq. (53)). ');
disp(' ');

disp('The variables a and c, and the function g are as defined in the paper.');
disp('The variable d is used to denote \delta, and pbar is used to denote \bar{p}.');
disp('We use the assumptions (same as in the paper): |a|>1, d>0, c^2>0.');
disp(' ');



%% Preliminary calculations.
disp(' ');
disp('##############################');
disp('## Preliminary calculations ##');
disp('##############################');

% (1) Positive solution to DARE: pbar (scalar version)
pbar_ = (a^2-1+c^2+S)/(2*c^2);
S_ = sqrt((a^2+c^2-1)^2 + 4*c^2);
% Sanity check:
%sanity1 = simplify(subs(g-p,p,subs(pbar_,S,S_)))

disp(' ');
disp('# Positive solution pbar to (scalar) discrete algebraic Riccati equation:');
disp('pbar =');
pretty(pbar_);
disp(' ');
disp('where S :=');
pretty(S_);
disp(' ');
disp('Notice that S>0.');
disp(' ');


% (2) Derivative g'(p)
dg = simplify(diff(g,p));

disp(' ');
disp('# Derivative g''(p):');
disp('dg := g''(p) =');
pretty(dg);
disp(' ');

% (3) p1 (as defined in Proposition 1)
p1_ = subs(g,p,pbar+d);

disp(' ');
disp('# Variable p1 (as defined in Proposition 1):');
disp('p1 = h(pbar+d) = g(pbar+d) =');
pretty(p1_);
disp(' ');



%% Calculations
disp(' ');
disp('###################################################################');
disp('## Show that BOUND := a^2*(pbar+d)/p1*g''(pbar+d) is less than 1. ##');
disp('###################################################################');

% (1) Define variable BOUND to be shown to be less than one.
bound1 = simplify(factor(subs(dg,p,pbar+d)*a^2*(pbar+d))/p1_);

disp(' ');
disp('# Define variable:');
disp('We define BOUND := a^2 * (pbar+d) / p1 * g''(pbar+d).  Substituting g''(pbar+d), we get');
disp('BOUND = ');
pretty(bound1);
disp(' ');


% (2) Substitute solution of DARE for pbar.
bound2 = subs(bound1,pbar,pbar_);

disp(' ');
disp('# Substitute pbar:')
disp('Substituting the positive solution of DARE (pbar) yields')
disp('BOUND = ');
pretty(bound2);
disp(' ');


% (3) Extract numerator and denominator
[num,den] = numden(bound2);
num = expand(num/2/c^2);  % cancel factor 2*c^2 in num and den
den = expand(den/2/c^2);

disp(' ');
disp('# Extract numerator and denominator:')
disp('BOUND = NUM/DEN, where');
disp(' ');
disp('NUM := ');
pretty(num);
disp(' ');
disp('DEN := ');
pretty(den);
disp(' ');
disp('Notice that DEN>0, since a^6 - a^2 = a^2*(a^4-1) is greater 0 (since |a|>1) and all other terms are positive.');
disp(' ');


% (4) Difference DEN - NUM > 0
% First replace S^2 by the expression in problem parameters 
% ((a^2+c^2-1)^2+4*c^2) in DEN; then compute DEN-NUM and simplify.
difference = expand(simplify(subs(den,S^2,S_^2) - num));

disp(' ');
disp('# Equivalence:')
disp('The following statements are equivalent: BOUND < 1  <=>  NUM/DEN < 1  <=> DEN - NUM > 0.');
disp('We substitute S^2 (with (a^2+c^2-1)^2+4*c^2, see above) and compute the difference DEN - NUM.  Simplification of the expression yields');
disp(' ');
disp('DEN - NUM = ');
pretty(difference)
disp(' ');
disp('which can be seen to be positive since all individual terms are positive.');

